#version 150

#moj_import <fog.glsl>
#moj_import <light.glsl>

uniform sampler2D Sampler0;
uniform sampler2D Sampler1;
uniform sampler2D Sampler2;

uniform vec4 ColorModulator;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;
uniform float GameTime;
uniform vec3 Light0_Direction;
uniform vec3 Light1_Direction;

in float vertexDistance;
in vec4 vertexColor;
in vec2 texCoord0;
in vec2 texCoord1;
in vec4 normal;
flat in vec4 tint;
flat in vec3 vNormal;
flat in vec4 texel;

out vec4 fragColor;

#define TEX_RES 16
#define ANIM_SPEED 750

void main() {
    ivec2 atlasSize = textureSize(Sampler0, 0);
    vec2 coords = texCoord0;
    float armorAmount = atlasSize.x / (TEX_RES * 4.0);
    coords.x /= armorAmount;
    float maxFrames = atlasSize.y / (TEX_RES * 2.0);
    coords.y /= maxFrames;
    float interpolClock = 0;
    float h_offset = 1.0 / armorAmount * (tint.b * 255);
    vec4 leatherCheck = texture(Sampler0, vec2(0.0, 1.0 / atlasSize.y));
    if (tint.r == 1.0 && tint.g == 1.0){
        coords.x += h_offset;
        vec4 animInfo = texture(Sampler0, vec2(h_offset, 0)) * 255;
        
        if (animInfo != vec4(0,0,0,255)){
            // oh god it's animated
            // animInfo = amount of frames, speed  
            int timer = int(GameTime * ANIM_SPEED * animInfo.g) % int(animInfo.r);
            interpolClock = fract(GameTime * ANIM_SPEED * animInfo.g);
            float v_offset = (TEX_RES * 2.0) / atlasSize.y * timer;
            coords.y += v_offset;
        }
    }
    vec4 vtc = minecraft_mix_light(Light0_Direction, Light1_Direction, vNormal, vec4(1,1,1,1)) * texel;
    vec4 texture = texture(Sampler0, coords);
    vec4 color;
    if (texture.g == texture.b){
        color = texture * vertexColor * ColorModulator;
    }else if(leatherCheck == vec4(1,1,1,1)){
        color = texture * vtc * ColorModulator;
    }else{
        color = texture * vertexColor * ColorModulator;
    }
    if (color.a < 0.1) discard;
    fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
}
